==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/nl-NL/localizations.php <==
<?php

return [

    'select_language' => 'Kies een taal',
    'languages' => [
        'en-US'=> 'Engels, VS',
        'en-GB'=> 'Engels, VK',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'Afrikaans',
        'ar-SA'=> 'Arabisch',
        'bg-BG'=> 'Bulgaars',
        'zh-CN'=> 'Chinees, vereenvoudigd',
        'zh-TW'=> 'Chinese, traditioneel',
        'ca-ES' => 'Catalaans',
        'hr-HR'=> 'Kroatisch',
        'cs-CZ'=> 'Tsjechisch',
        'da-DK'=> 'Deens',
        'nl-NL'=> 'Nederlands',
        'en-ID'=> 'Engels (Indonesië)',
        'et-EE'=> 'Estlands',
        'fil-PH'=> 'Filipijns',
        'fi-FI'=> 'Fins',
        'fr-FR'=> 'Frans',
        'de-DE'=> 'Duits',
        'de-if'=> 'Duits (Informeel)',
        'el-GR'=> 'Grieks',
        'he-IL'=> 'Hebreeuws',
        'hu-HU'=> 'Hongaars',
        'is-IS' => 'IJslands',
        'id-ID'=> 'Indonesisch',
        'ga-IE'=> 'Iers',
        'it-IT'=> 'Italiaans',
        'ja-JP'=> 'Japans',
        'km-KH'=>'Khmer',
        'ko-KR'=> 'Koreaans',
        'lt-LT'=>'Litouws',
        'lv-LV'=> 'Lets',
        'mk-MK'=> 'Macedonisch',
        'ms-MY'=> 'Maleis',
        'mi-NZ'=> 'Maori',
        'mn-MN'=> 'Mongools',
        'no-NO'=> 'Noors',
        'fa-IR'=> 'Perzisch',
        'pl-PL'=> 'Pools',
        'pt-PT'=> 'Portugees',
        'pt-BR'=> 'Portugees (Braziliaans)',
        'ro-RO'=> 'Roemeens',
        'ru-RU'=> 'Russisch',
        'sr-CS' => 'Servisch (latijns)',
        'sk-SK'=> 'Slowaaks',
        'sl-SI'=> 'Sloveens',
        'es-ES'=> 'Spaans',
        'es-CO'=> 'Spaans (Colombia)',
        'es-MX'=> 'Spaans (Mexico)',
        'es-VE'=> 'Spaans (Venezuela)',
        'sv-SE'=> 'Zweeds',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamil',
        'th-TH'=> 'Thais',
        'tr-TR'=> 'Turks',
        'uk-UA'=> 'Oekraïens',
        'vi-VN'=> 'Vietnamees',
        'cy-GB'=> 'Welsh',
        'zu-ZA'=> 'Zoeloe',
    ],

    'select_country' => 'Selecteer een land',
    
    'countries' => [
        'AC'=>'Ascensie Eiland',
        'AD'=>'Andorra',
        'AE'=>'Verenigde Arabische Emiraten',
        'AF'=>'Afghanistan',
        'AG'=>'Antigua en Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Albanië',
        'AM'=>'Armenië',
        'AN'=>'Nederlandse Antillen',
        'AO'=>'Angola',
        'AQ'=>'Antarctica',
        'AR'=>'Argentinië',
        'AS'=>'Amerikaans-Samoa',
        'AT'=>'Oostenrijk',
        'AU'=>'Australië',
        'AW'=>'Aruba',
        'AX'=>'AŞ/UZET land',
        'AZ'=>'Azerbeidzjan',
        'BA'=>'Bosnië en Herzegowina',
        'BB'=>'Barbados',
        'BE'=>'België',
        'BD'=>'Bangladesh',
        'BF'=>'Burkina Faso',
        'BG'=>'Bulgarije',
        'BH'=>'Bahrein',
        'BI'=>'Boeroendi',
        'BJ'=>'Benin',
        'BM'=>'Bermuda',
        'BN'=>'Brunei Darussalam',
        'BO'=>'Bolivië',
        'BR'=>'Brazilië',
        'BS'=>'Bahama’s',
        'BT'=>'Bhutan',
        'BV'=>'Bouveteiland',
        'BW'=>'Botswana',
        'BY'=>'Wit-Rusland',
        'BZ'=>'Belize',
        'CA'=>'Canada',
        'CC'=>'Cocoseilanden (Keelingeilanden)',
        'CD'=>'Congo, Democratische Republiek',
        'CF'=>'Centraal-Afrikaanse Republiek',
        'CG'=>'Congo (Republiek)',
        'CH'=>'Zwitserland',
        'CI'=>'Ivoorkust',
        'CK'=>'Cook Eilanden',
        'CL'=>'Chili',
        'CM'=>'Kameroen',
        'CN'=>'Volksrepubliek China',
        'CO'=>'Colombia',
        'CR'=>'Costa Rica',
        'CU'=>'Cuba',
        'CV'=>'Kaapverdië',
        'CX'=>'Kersteiland',
        'CY'=>'Cyprus',
        'CZ'=>'Tsjechische Republiek',
        'DE'=>'Duitsland',
        'DJ'=>'Djibouti',
        'DK'=>'Denemarken',
        'DM'=>'Dominica',
        'DO'=>'Dominicaanse Republiek',
        'DZ'=>'Algerije',
        'EC'=>'Ecuador',
        'EE'=>'Estland',
        'EG'=>'Egypte',
        'ER'=>'Eritrea',
        'ES'=>'Spanje',
        'ET'=>'Ethiopië',
        'EU'=>'Europese Unie',
        'FI'=>'Finland',
        'FJ'=>'Fiji',
        'FK'=>'Falklandeilanden (Malvinas)',
        'FM'=>'Micronesië, Gefedereerde Staten van',
        'FO'=>'Faroe Eilanden',
        'FR'=>'Frankrijk',
        'GA'=>'Gabon',
        'GD'=>'Grenada',
        'GE'=>'Georgië',
        'GF'=>'Frans-Guyana',
        'GG'=>'Guernsey',
        'GH'=>'Ghana',
        'GI'=>'Gibraltar',
        'GL'=>'Groenland',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadeloupe',
        'GQ'=>'Equatoriaal-Guinea',
        'GR'=>'Griekenland',
        'GS'=>'Zuid-Georgia en de Zuidelijke Sandwicheilanden',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Guinea-Bissau',
        'GY'=>'Gyana',
        'HK'=>'Hong Kong',
        'HM'=>'Gehoord en McDonaldeilanden',
        'HN'=>'Honduras',
        'HR'=>'Kroatië (lokale naam: Hrvatska)',
        'HT'=>'Haïti',
        'HU'=>'Hongarije',
        'ID'=>'Indonesië',
        'IE'=>'Ierland',
        'IL'=>'Israël',
        'IM'=>'Eiland van Man',
        'IN'=>'Indië',
        'IO'=>'Brits Indische Oceaanterritorium',
        'IQ'=>'Irak',
        'IR'=>'Iran, Islamitische Republiek Van',
        'IS'=>'Ijsland',
        'IT'=>'Italië',
        'JE'=>'Jersey',
        'JM'=>'Jamaica',
        'JO'=>'Jordanië',
        'JP'=>'Japan',
        'KE'=>'Kenia',
        'KG'=>'Kirgizië',
        'KH'=>'Cambodja',
        'KI'=>'Kiribati',
        'KM'=>'Comoren',
        'KN'=>'Saint Kitts en Nevis',
        'KR'=>'Zuid-Korea',
        'KW'=>'Koeweit',
        'KY'=>'Kaaiman Eilanden',
        'KZ'=>'Kazachstan',
        'LA'=>'Lao Democratische Volksrepubliek',
        'LB'=>'Libanon',
        'LC'=>'Sint-Lucia',
        'LI'=>'Liechtenstein',
        'LK'=>'Sri Lanka',
        'LR'=>'Liberië',
        'LS'=>'Lesotho',
        'LT'=>'Litouwen',
        'LU'=>'Luxemburg',
        'LV'=>'Letland',
        'LY'=>'Libië',
        'MA'=>'Marokko',
        'MC'=>'Monaco',
        'MD'=>'Moldavië, Republiek van',
        'ME'=>'Montenegro',
        'MG'=>'Madagascar',
        'MH'=>'Marshall Eilanden',
        'MK'=>'Macedonië, De Voormalige Joegoslavische Republiek van',
        'ML'=>'Mali',
        'MM'=>'Myanmar',
        'MN'=>'Mongolië',
        'MO'=>'Macau',
        'MP'=>'Noordelijke Marianen eilanden',
        'MQ'=>'Martinique',
        'MR'=>'Mauritanië',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Malediven',
        'MW'=>'Malawi',
        'MX'=>'Mexico',
        'MY'=>'Maleisië',
        'MZ'=>'Mozambique',
        'NA'=>'Namibië',
        'NC'=>'Nieuw Caledonië',
        'NE'=>'Niger',
        'NF'=>'Norfolk eiland',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Nederland',
        'NO'=>'Noorwegen',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'Niew Zeeland',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'Frans-Polynesië',
        'PG'=>'Papua Nieuw-Guinea',
        'PH'=>'Filippijnen, Republiek van de',
        'PK'=>'Pakistan',
        'PL'=>'Polen',
        'PM'=>'Saint-Pierre en Miquelon',
        'PN'=>'Pitcairn',
        'PR'=>'Puerto Rico',
        'PS'=>'Palestina',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Qatar',
        'RE'=>'Reünie',
        'RO'=>'Roemenië',
        'RS'=>'Servië',
        'RU'=>'Rusland',
        'RW'=>'Rwanda',
        'SA'=>'Saoedi-Arabië',
        'UK'=>'Schotland',
        'SB'=>'Solomon eilanden',
        'SC'=>'Seychellen',
        'SS'=>'Zuid-Soedan',
        'SD'=>'Soedan',
        'SE'=>'Zweden',
        'SG'=>'Singapour',
        'SH'=>'Sint-Helena',
        'SI'=>'Slovenië',
        'SJ'=>'Svalbard en Jan Mayen Eilanden',
        'SK'=>'Slowakije (Slovaakse Republiek)',
        'SL'=>'Sierra Leone',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalië',
        'SR'=>'Suriname',
        'ST'=>'Sao Tomé en Principe',
        'SU'=>'Sovjet-Unie',
        'SV'=>'El Salvador',
        'SY'=>'Syrische Arabische Republiek',
        'SZ'=>'Swaziland',
        'TC'=>'Turks- en Caicoseilanden',
        'TD'=>'Tsjaad',
        'TF'=>'Franse Zuidelijke Gebieden',
        'TG'=>'Togo',
        'TH'=>'Thailand',
        'TJ'=>'Tajikistan',
        'TK'=>'Tokelau',
        'TI'=>'Oost-Timor',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunesië',
        'TO'=>'Tonga',
        'TP'=>'Oost-Timor (oude code)',
        'TR'=>'Turkije',
        'TT'=>'Trinidad en Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Taiwan',
        'TZ'=>'Tanzania, Verenigde Republiek van',
        'UA'=>'Oekraïne',
        'UG'=>'Oeganda',
        'UK'=>'Verenigd Koninkrijk',
        'US'=>'Verenigde Staten',
        'UM'=>'Amerikaanse Kleinere Afgelegen Eilanden',
        'UY'=>'Uruguay',
        'UZ'=>'Oezbekistan',
        'VA'=>'Vaticaanstad (Heilige Zie)',
        'VC'=>'Saint Vincent en de Grenadines',
        'VE'=>'Venezuela',
        'VG'=>'Britse Maagdeneilanden',
        'VI'=>'Amerikaanse Maagdeneilanden',
        'VN'=>'Vietnam',
        'VU'=>'Vanuatu',
        'WF'=>'Wallis en Futuna eilanden',
        'WS'=>'Samoa',
        'YE'=>'Jemen',
        'YT'=>'Mayotte',
        'ZA'=>'Zuid-Afrika',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/nl-NL/localizations.php <==
<?php

return [

    'select_language' => 'Selecteer een taal',
    'languages' => [
        'en-US'=> 'Engels, VS',
        'en-GB'=> 'Engels, VK',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'Afrikaans',
        'ar-SA'=> 'Arabisch',
        'bg-BG'=> 'Bulgaars',
        'zh-CN'=> 'Chinees, vereenvoudigd',
        'zh-TW'=> 'Chinese, traditioneel',
        'ca-ES' => 'Catalaans',
        'hr-HR'=> 'Kroatisch',
        'cs-CZ'=> 'Tsjechisch',
        'da-DK'=> 'Deens',
        'nl-NL'=> 'Nederlands',
        'en-ID'=> 'Engels (Indonesië)',
        'et-EE'=> 'Estlands',
        'fil-PH'=> 'Filipijns',
        'fi-FI'=> 'Fins',
        'fr-FR'=> 'Frans',
        'de-DE'=> 'Duits',
        'de-if'=> 'Duits (Informeel)',
        'el-GR'=> 'Grieks',
        'he-IL'=> 'Hebreeuws',
        'hu-HU'=> 'Hongaars',
        'is-IS' => 'IJslands',
        'id-ID'=> 'Indonesisch',
        'ga-IE'=> 'Iers',
        'it-IT'=> 'Italiaans',
        'ja-JP'=> 'Japans',
        'km-KH'=>'Khmer',
        'ko-KR'=> 'Koreaans',
        'lt-LT'=>'Litouws',
        'lv-LV'=> 'Lets',
        'mk-MK'=> 'Macedonisch',
        'ms-MY'=> 'Maleis',
        'mi-NZ'=> 'Maori',
        'mn-MN'=> 'Mongools',
        //'no-NO'=> 'Norwegian',
        'nb-NO'=> 'Noors Bokmål',
        //'nn-NO'=> 'Norwegian Nynorsk',
        'fa-IR'=> 'Perzisch',
        'pl-PL'=> 'Pools',
        'pt-PT'=> 'Portugees',
        'pt-BR'=> 'Portugees (Braziliaans)',
        'ro-RO'=> 'Roemeens',
        'ru-RU'=> 'Russisch',
        'sr-CS' => 'Servisch (latijns)',
        'sk-SK'=> 'Slowaaks',
        'sl-SI'=> 'Sloveens',
        'so-SO'=> 'Somali',
        'es-ES'=> 'Spaans',
        'es-CO'=> 'Spaans (Colombia)',
        'es-MX'=> 'Spaans (Mexico)',
        'es-VE'=> 'Spaans (Venezuela)',
        'sv-SE'=> 'Zweeds',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamil',
        'th-TH'=> 'Thais',
        'tr-TR'=> 'Turks',
        'uk-UA'=> 'Oekraïens',
        'vi-VN'=> 'Vietnamees',
        'cy-GB'=> 'Welsh',
        'zu-ZA'=> 'Zoeloe',
    ],

    'select_country' => 'Selecteer een Land',
    
    'countries' => [
        'AC'=>'Ascensie Eiland',
        'AD'=>'Andorra',
        'AE'=>'Verenigde Arabische Emiraten',
        'AF'=>'Afghanistan',
        'AG'=>'Antigua en Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Albanië',
        'AM'=>'Armenië',
        'AN'=>'Nederlandse Antillen',
        'AO'=>'Angola',
        'AQ'=>'Antarctica',
        'AR'=>'Argentinië',
        'AS'=>'Amerikaans-Samoa',
        'AT'=>'Oostenrijk',
        'AU'=>'Australië',
        'AW'=>'Aruba',
        'AX'=>'AŞ/UZET land',
        'AZ'=>'Azerbeidzjan',
        'BA'=>'Bosnië en Herzegowina',
        'BB'=>'Barbados',
        'BE'=>'België',
        'BD'=>'Bangladesh',
        'BF'=>'Burkina Faso',
        'BG'=>'Bulgarije',
        'BH'=>'Bahrein',
        'BI'=>'Boeroendi',
        'BJ'=>'Benin',
        'BM'=>'Bermuda',
        'BN'=>'Brunei Darussalam',
        'BO'=>'Bolivië',
        'BR'=>'Brazilië',
        'BS'=>'Bahama’s',
        'BT'=>'Bhutan',
        'BV'=>'Bouveteiland',
        'BW'=>'Botswana',
        'BY'=>'Wit-Rusland',
        'BZ'=>'Belize',
        'CA'=>'Canada',
        'CC'=>'Cocoseilanden (Keelingeilanden)',
        'CD'=>'Congo, Democratische Republiek',
        'CF'=>'Centraal-Afrikaanse Republiek',
        'CG'=>'Congo (Republiek)',
        'CH'=>'Zwitserland',
        'CI'=>'Ivoorkust',
        'CK'=>'Cook Eilanden',
        'CL'=>'Chili',
        'CM'=>'Kameroen',
        'CN'=>'Volksrepubliek China',
        'CO'=>'Colombia',
        'CR'=>'Costa Rica',
        'CU'=>'Cuba',
        'CV'=>'Kaapverdië',
        'CX'=>'Kersteiland',
        'CY'=>'Cyprus',
        'CZ'=>'Tsjechische Republiek',
        'DE'=>'Duitsland',
        'DJ'=>'Djibouti',
        'DK'=>'Denemarken',
        'DM'=>'Dominica',
        'DO'=>'Dominicaanse Republiek',
        'DZ'=>'Algerije',
        'EC'=>'Ecuador',
        'EE'=>'Estland',
        'EG'=>'Egypte',
        'GB-ENG'=>'Engeland',
        'ER'=>'Eritrea',
        'ES'=>'Spanje',
        'ET'=>'Ethiopië',
        'EU'=>'Europese Unie',
        'FI'=>'Finland',
        'FJ'=>'Fiji',
        'FK'=>'Falklandeilanden (Malvinas)',
        'FM'=>'Micronesië, Gefedereerde Staten van',
        'FO'=>'Faroe Eilanden',
        'FR'=>'Frankrijk',
        'GA'=>'Gabon',
        'GD'=>'Grenada',
        'GE'=>'Georgië',
        'GF'=>'Frans-Guyana',
        'GG'=>'Guernsey',
        'GH'=>'Ghana',
        'GI'=>'Gibraltar',
        'GL'=>'Groenland',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadeloupe',
        'GQ'=>'Equatoriaal-Guinea',
        'GR'=>'Griekenland',
        'GS'=>'Zuid-Georgia en de Zuidelijke Sandwicheilanden',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Guinea-Bissau',
        'GY'=>'Gyana',
        'HK'=>'Hong Kong',
        'HM'=>'Gehoord en McDonaldeilanden',
        'HN'=>'Honduras',
        'HR'=>'Kroatië (lokale naam: Hrvatska)',
        'HT'=>'Haïti',
        'HU'=>'Hongarije',
        'ID'=>'Indonesië',
        'IE'=>'Ierland',
        'IL'=>'Israël',
        'IM'=>'Eiland van Man',
        'IN'=>'Indië',
        'IO'=>'Brits Indische Oceaanterritorium',
        'IQ'=>'Irak',
        'IR'=>'Iran, Islamitische Republiek Van',
        'IS'=>'Ijsland',
        'IT'=>'Italië',
        'JE'=>'Jersey',
        'JM'=>'Jamaica',
        'JO'=>'Jordanië',
        'JP'=>'Japan',
        'KE'=>'Kenia',
        'KG'=>'Kirgizië',
        'KH'=>'Cambodja',
        'KI'=>'Kiribati',
        'KM'=>'Comoren',
        'KN'=>'Saint Kitts en Nevis',
        'KR'=>'Zuid-Korea',
        'KW'=>'Koeweit',
        'KY'=>'Kaaiman Eilanden',
        'KZ'=>'Kazachstan',
        'LA'=>'Lao Democratische Volksrepubliek',
        'LB'=>'Libanon',
        'LC'=>'Sint-Lucia',
        'LI'=>'Liechtenstein',
        'LK'=>'Sri Lanka',
        'LR'=>'Liberië',
        'LS'=>'Lesotho',
        'LT'=>'Litouwen',
        'LU'=>'Luxemburg',
        'LV'=>'Letland',
        'LY'=>'Libië',
        'MA'=>'Marokko',
        'MC'=>'Monaco',
        'MD'=>'Moldavië, Republiek van',
        'ME'=>'Montenegro',
        'MG'=>'Madagascar',
        'MH'=>'Marshall Eilanden',
        'MK'=>'Macedonië, De Voormalige Joegoslavische Republiek van',
        'ML'=>'Mali',
        'MM'=>'Myanmar',
        'MN'=>'Mongolië',
        'MO'=>'Macau',
        'MP'=>'Noordelijke Marianen eilanden',
        'MQ'=>'Martinique',
        'MR'=>'Mauritanië',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Malediven',
        'MW'=>'Malawi',
        'MX'=>'Mexico',
        'MY'=>'Maleisië',
        'MZ'=>'Mozambique',
        'NA'=>'Namibië',
        'NC'=>'Nieuw Caledonië',
        'NE'=>'Niger',
        'NF'=>'Norfolk eiland',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Nederland',
        'GB-NIR' => 'Noord-Ierland',
        'NO'=>'Noorwegen',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'Niew Zeeland',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'Frans-Polynesië',
        'PG'=>'Papua Nieuw-Guinea',
        'PH'=>'Filippijnen, Republiek van de',
        'PK'=>'Pakistan',
        'PL'=>'Polen',
        'PM'=>'Saint-Pierre en Miquelon',
        'PN'=>'Pitcairn',
        'PR'=>'Puerto Rico',
        'PS'=>'Palestina',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Qatar',
        'RE'=>'Reünie',
        'RO'=>'Roemenië',
        'RS'=>'Servië',
        'RU'=>'Rusland',
        'RW'=>'Rwanda',
        'SA'=>'Saoedi-Arabië',
        'GB-SCT'=>'Schotland',
        'SB'=>'Solomon eilanden',
        'SC'=>'Seychellen',
        'SS'=>'Zuid-Soedan',
        'SD'=>'Soedan',
        'SE'=>'Zweden',
        'SG'=>'Singapour',
        'SH'=>'Sint-Helena',
        'SI'=>'Slovenië',
        'SJ'=>'Svalbard en Jan Mayen Eilanden',
        'SK'=>'Slowakije (Slovaakse Republiek)',
        'SL'=>'Sierra Leone',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalië',
        'SR'=>'Suriname',
        'ST'=>'Sao Tomé en Principe',
        'SU'=>'Sovjet-Unie',
        'SV'=>'El Salvador',
        'SY'=>'Syrische Arabische Republiek',
        'SZ'=>'Swaziland',
        'TC'=>'Turks- en Caicoseilanden',
        'TD'=>'Tsjaad',
        'TF'=>'Franse Zuidelijke Gebieden',
        'TG'=>'Togo',
        'TH'=>'Thailand',
        'TJ'=>'Tajikistan',
        'TK'=>'Tokelau',
        'TI'=>'Oost-Timor',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunesië',
        'TO'=>'Tonga',
        'TP'=>'Oost-Timor (oude code)',
        'TR'=>'Turkije',
        'TT'=>'Trinidad en Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Taiwan',
        'TZ'=>'Tanzania, Verenigde Republiek van',
        'UA'=>'Oekraïne',
        'UG'=>'Oeganda',
        'UK'=>'Verenigd Koninkrijk',
        'US'=>'Verenigde Staten',
        'UM'=>'Amerikaanse Kleinere Afgelegen Eilanden',
        'UY'=>'Uruguay',
        'UZ'=>'Oezbekistan',
        'VA'=>'Vaticaanstad (Heilige Zie)',
        'VC'=>'Saint Vincent en de Grenadines',
        'VE'=>'Venezuela',
        'VG'=>'Britse Maagdeneilanden',
        'VI'=>'Amerikaanse Maagdeneilanden',
        'VN'=>'Vietnam',
        'VU'=>'Vanuatu',
        'GB-WLS' =>'Wales',
        'WF'=>'Wallis en Futuna eilanden',
        'WS'=>'Samoa',
        'YE'=>'Jemen',
        'YT'=>'Mayotte',
        'ZA'=>'Zuid-Afrika',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];
